@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 # -*- coding: utf-8 -*-
 
 ### BEGIN LICENSE
@@ -23,12 +23,16 @@
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-import urllib2
+import urllib.request, urllib.error, urllib.parse
 import json
 import apt
+from models.globals import Globals
+from .application import Application
 
-from application import Application
 
+import gettext
+gettext.textdomain("ubuntu-kylin-software-center")
+_ = gettext.gettext
 #This class is the abstraction of a 
 class Category:
 
@@ -76,7 +80,10 @@ class Category:
         except:
             app = None
         else:
-            if app.package is None or app.package.candidate is None:
+            try:
+                if app.package is None or app.package.candidate is None:
+                    app = None
+            except:
                 app = None
         return app
 
@@ -85,7 +92,7 @@ class Category:
         up = 0
         all = 0
         if(self.apps is not None):
-            for (appname, app) in self.apps.iteritems():
+            for (appname, app) in list(self.apps.items()):
                 if app.package is None or app.package.candidate is None:
                     continue
                 all = all + 1
@@ -101,11 +108,14 @@ if __name__ == "__main__":
 
     cache = apt.Cache()
     cache.open()
-    print len(cache)
+    if (Globals.DEBUG_SWITCH):
+        print((len(cache)))
 
-    cat1 = Category("devel","开发工具","",[])
-    print cat1.name
-    print cat1.apps
+    #cat1 = Category("devel","开发工具","",[])
+    cat1 = Category("devel", _("Development tools"), "", [])
+    if (Globals.DEBUG_SWITCH):
+        print((cat1.name))
+        print((cat1.apps))
 
      
 
