@@ -19,14 +19,16 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 from backend.service.appmanager import  AppManager
-
+from models.globals import Globals
 
 if __name__ == "__main__":
 
     #初始化打开cache
     appManager = AppManager()
     appManager.open_cache()
-    print appManager.name
+    if (Globals.DEBUG_SWITCH):
+        print(appManager.name)
     #加载软件分类
     appManager.load_categories()
-    print appManager.cat_list
+    if (Globals.DEBUG_SWITCH):
+        print(appManager.cat_list)
