@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 # -*- coding: utf-8 -*-
 
 ### BEGIN LICENSE
@@ -22,12 +22,16 @@
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-
-from PyQt4.QtGui import *
-from PyQt4.QtCore import *
+from PyQt5.QtWidgets import *
+from PyQt5.QtGui import *
+from PyQt5.QtCore import *
 from models.enums import UBUNTUKYLIN_RES_PATH
 from models.globals import Globals
 
+import gettext
+gettext.textdomain("ubuntu-kylin-software-center")
+_ = gettext.gettext
+
 class LoadingDiv(QWidget):
 
     ngif = []
@@ -39,10 +43,13 @@ class LoadingDiv(QWidget):
         self.setWindowFlags(Qt.FramelessWindowHint)
         self.setAttribute(Qt.WA_TranslucentBackground, True)
 
-        self.switchTimer = QTimer(self)
-        self.switchTimer.timeout.connect(self.slot_switch_animation_step)
+        # self.switchTimer = QTimer(self)
+        # self.switchTimer.timeout.connect(self.slot_switch_animation_step)
 
-        self.load_png()
+        #self.setWindowTitle("银河麒麟软件商店")
+        self.setWindowTitle(_("Galaxy kylin softare store"))
+
+        # self.load_png()
 
         # launch loading
         if(parent == None):
@@ -56,8 +63,12 @@ class LoadingDiv(QWidget):
         else:
             self.setGeometry(0, 0, Globals.MAIN_WIDTH, Globals.MAIN_HEIGHT)
 
+
+        self.gif = QMovie(UBUNTUKYLIN_RES_PATH + "loadgif.gif")
         self.loadinggif = QLabel(self)
         self.loadinggif.setGeometry(Globals.MAIN_WIDTH / 2 - 350 / 2, Globals.MAIN_HEIGHT / 2 - 350 / 2, 350, 350)
+        self.loadinggif.setMovie(self.gif)
+
 
         # self.loadingtext = QLabel(self)
         # self.loadingtext.setGeometry()
@@ -65,27 +76,34 @@ class LoadingDiv(QWidget):
         self.raise_()
         self.hide()
 
-    def load_png(self):
-        for i in range(1, 41):
-            img = QPixmap("res/loading/" + str(i) + ".png")
-            self.ngif.append(img)
+    # def load_png(self):
+    #     for i in range(1, 18):
+    #         img = QPixmap("res/loading/" + str(i) + ".png")
+    #         self.ngif.append(img)
+    #
+    # def slot_switch_animation_step(self):
+    #     if(self.currentpage == 17):
+    #         self.currentpage = 1
+    #
+    #     self.loadinggif.setPixmap(self.ngif[self.currentpage])
+    #
+    #     self.currentpage = self.currentpage + 1
 
-    def slot_switch_animation_step(self):
-        if(self.currentpage == 40):
-            self.currentpage = 24
-
-        self.loadinggif.setPixmap(self.ngif[self.currentpage])
-
-        self.currentpage = self.currentpage + 1
-
-    def start_loading(self, loadingText):
-        # self.loadingtext.setText(loadingText)
-        self.currentpage = 0
-        self.switchTimer.start(60)
+    # def start_loading(self):
+    #     # self.loadingtext.setText(loadingText)
+    #     self.currentpage = 0
+    #     self.switchTimer.start(200)
+    #     self.show()
+    #
+    # def stop_loading(self):
+    #     self.switchTimer.stop()
+    #     self.hide()
+    def start_loading(self):
+        self.gif.start()
         self.show()
 
     def stop_loading(self):
-        self.switchTimer.stop()
+        self.gif.stop()
         self.hide()
 
 
@@ -112,7 +130,7 @@ class MiniLoadingDiv(QWidget):
 
         self.gif = QMovie(UBUNTUKYLIN_RES_PATH + "loading.gif")
         self.loadinggif = QLabel(self)
-        self.loadinggif.setGeometry(self.width_ / 2 - 25 + offsetx, self.height_ / 2 - 25 + offsety, 50, 50)
+        self.loadinggif.setGeometry(self.width_ / 2 - 50 + offsetx, self.height_ / 2 - 25 + offsety, 50, 50)
         self.loadinggif.setMovie(self.gif)
         # self.loadingtext = QLabel(self)
         # self.loadingtext.setGeometry(self.loadinggif.x() + 25 - 150, self.loadinggif.y() + 55, 300, 20)
@@ -126,4 +144,4 @@ class MiniLoadingDiv(QWidget):
 
     def stop_loading(self):
         self.gif.stop()
-        self.hide()
\ No newline at end of file
+        self.hide()
