@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 # -*- coding: utf-8 -*-
 
 ### BEGIN LICENSE
@@ -22,9 +22,8 @@
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-
-from PyQt4.QtGui import *
-from PyQt4.QtCore import *
+from PyQt5.QtWidgets import *
+from PyQt5.QtCore import *
 from ui.ukcmtw import Ui_CommentWidget
 from ui.starwidget import StarWidget
 from models.enums import setLongTextToElideFormat
@@ -58,4 +57,4 @@ class ReviewWidget(QWidget):
     def ui_init(self):
         self.ui = Ui_CommentWidget()
         self.ui.setupUi(self)
-        #self.show() 'for lp Bug #1372283, just in test. There my be another way'
\ No newline at end of file
+        #self.show() 'for lp Bug #1372283, just in test. There my be another way'
