@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 # -*- coding: utf-8 -*-
 
 ### BEGIN LICENSE
@@ -26,12 +26,12 @@
 
 
 import os
-import re
-import subprocess
 import xdg.DesktopEntry
-from models.enums import Specials
+import time
+from models.enums import Specials, PKG_NAME
+from models.globals import Globals
+import subprocess
 
-import commands
 
 def RemoveArgs(Execline):
     NewExecline = []
@@ -39,21 +39,24 @@ def RemoveArgs(Execline):
         elem = elem.replace("'","")
         elem = elem.replace("\"", "")
         if elem not in Specials:
-            print elem
+            if (Globals.DEBUG_SWITCH):
+                print(elem)
             NewExecline.append(elem)
     return NewExecline
 
 # Actually execute the command
 
 def Execute(cmd):
-    if isinstance( cmd, str ) or isinstance( cmd, unicode):
+    if isinstance( cmd, str ) or isinstance( cmd, str):
         if (cmd.find("/home/") >= 0) or (cmd.find("su-to-root") >= 0) or (cmd.find("\"") >= 0):
-            print "running manually..."
+            if (Globals.DEBUG_SWITCH):
+                print("running manually...")
             try:
                 os.system(cmd + " &")
                 return True
-            except Exception, detail:
-                print detail
+            except Exception as detail:
+                if (Globals.DEBUG_SWITCH):
+                    print(detail)
                 return False
     cmd = cmd.split()
     cmd = RemoveArgs(cmd)
@@ -64,53 +67,39 @@ def Execute(cmd):
         #subprocess.Popen( cmd ) // use os.system instead of popen so children don't end up in zombie waiting for us to wait() for them
         os.system(string)
         return True
-    except Exception, detail:
-        print detail
+    except Exception as detail:
+        if (Globals.DEBUG_SWITCH):
+            print(detail)
         return False
 
 
 def get_run_command(pkgname):
     # 对一些特殊软件单独处理
-    if pkgname == 'wps-office':
-        pkgname = 'wps-office-wps'
-    elif pkgname == 'uget':
-        pkgname = 'uget-gtk'
-    elif pkgname == 'eclipse-platform':
-        pkgname = 'eclipse'
-    elif pkgname == 'software-center':
-        pkgname = 'ubuntu-software-center'
-    elif pkgname == "sogoupinyin":
-        pkgname = "fcitx-ui-sogou-qimpanel"
-    elif pkgname == "mathwar":
-        pkgname = "MathWar"
-    elif pkgname == "gnome-disk-utility":
-        pkgname = "gnome-disks"
-    elif pkgname == "kino":
-        pkgname = "Kino"
-    elif pkgname == "monajat-applet":
-        pkgname = "monajat"
-    elif pkgname == "system-config-printer-applet":
-        pkgname = "system-config-printer"
-    elif pkgname == "xterm":
-        pkgname = "debian-uxterm"
-    elif pkgname == "virtualbox-qt":
-        pkgname = "virtualbox"
 
-    # fd = os.popen('find /usr/share/applications/ -name "%s.desktop" | xargs grep "Exec"' %pkgname)
-    # exc = fd.read()
-    # fd.close()
     fullcmd = ""
+
+    # moshengren add
+    if pkgname in PKG_NAME:
+        pkgname=PKG_NAME[pkgname]
+
     desktopfile = "/usr/share/applications/" + pkgname + ".desktop"
-    if not os.path.exists(desktopfile):
-        if pkgname == "gnome-screenshot":
-            pkgname = "org.gnome.Screenshot"
-        if pkgname == "gnome-mines":
-            pkgname = "gnomine"
-        desktopfile = "/usr/share/applications/" + pkgname + ".desktop"
+
     if os.path.exists(desktopfile):
         DeskTopEntry = xdg.DesktopEntry.DesktopEntry(desktopfile)
         fullcmd = DeskTopEntry.getExec()
 
+    if fullcmd == "":
+        user_desktop_path = os.path.join(os.path.expanduser("~"), ".local", "share", "applications")
+        if(os.path.exists(user_desktop_path) == False):
+            user_desktop_path = os.path.join(os.path.expanduser("~"), '桌面')
+
+        desktopfile = user_desktop_path + "/" + pkgname + ".desktop"
+
+        if os.path.exists(desktopfile):
+            time.sleep(0.5)
+            DeskTopEntry = xdg.DesktopEntry.DesktopEntry(desktopfile)
+            fullcmd = DeskTopEntry.getExec()
+
     # command = ['']
     # # 截取运行指令部分
     # if exc:
@@ -130,7 +119,8 @@ def get_run_command(pkgname):
 def run_app(pkgname):
     cmd = get_run_command(pkgname)
     if cmd != "":
-        print("\n#####run_app:",cmd)
+        if (Globals.DEBUG_SWITCH):
+            print(("\n#####run_app:",cmd))
         Execute(cmd)
     # #p = subprocess.Popen(cmd, stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=False)
     # os.system(cmd[0] + "&")#fixed bug 1402953
